/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.cli.core.exception;

/**
 * Command execution exception.
 */
public class CommandExecutionException extends RuntimeException {

    private final String commandId;

    private final String reason;

    public CommandExecutionException(String commandId, String reason) {
        this.commandId = commandId;
        this.reason = reason;
    }

    /**
     * Command identifier getter.
     *
     * @return command identifier.
     */
    public String getCommandId() {
        return commandId;
    }

    /**
     * Exception reason getter.
     *
     * @return exception reason.
     */
    public String getReason() {
        return reason;
    }

    @Override
    public String toString() {
        return super.toString();
    }
}
