/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.pagememory.mem;

import java.io.IOException;
import org.apache.ignite.internal.pagememory.PageMemory;
import org.apache.ignite.lang.IgniteInternalException;

/**
 * Exception that signifies that there's no more available page in the data region.
 *
 * @see PageMemory#allocatePage(int, int, byte)
 */
public class IgniteOutOfMemoryException extends IgniteInternalException {
    /** Serial version uid. */
    private static final long serialVersionUID = 0L;

    /**
     * Constructor.
     */
    public IgniteOutOfMemoryException() {
        // No-op.
    }

    /**
     * Constructor.
     *
     * @param msg Error message.
     */
    public IgniteOutOfMemoryException(String msg) {
        super(msg);
    }

    /**
     * Constructor.
     *
     * @param msg Error message.
     * @param e Cause exception.
     */
    public IgniteOutOfMemoryException(String msg, IOException e) {
        super(msg, e);
    }
}
