/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.configuration;

import static java.util.stream.Collectors.toList;
import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.hasSize;

import java.util.List;
import org.junit.jupiter.api.Test;

/**
 * Tests for {@link ServiceLoaderModulesProvider}.
 */
class ServiceLoaderModulesProviderTest {
    private final ServiceLoaderModulesProvider provider = new ServiceLoaderModulesProvider();

    @Test
    void loadsModulesDefinedAsServicesInMetaInf() {
        List<ConfigurationModule> testModules = provider.modules(getClass().getClassLoader()).stream()
                .filter(module -> module.getClass().equals(TestConfigurationModule.class))
                .collect(toList());

        assertThat(testModules, hasSize(1));
    }

    @Test
    void loadsModulesWhenClassLoaderIsNull() {
        List<ConfigurationModule> testModules = provider.modules(null).stream()
                .filter(module -> module.getClass().equals(TestConfigurationModule.class))
                .collect(toList());

        assertThat(testModules, hasSize(1));
    }
}
